@@ -15,7 +15,6 @@
 #include <QApplication>
 #include <kglobal.h>
 #include <kmainwindow.h>
-#include <kmenubar.h>
 #include "kstatusbartest.h"
 
 testWindow::testWindow(QWidget *)
@@ -26,7 +25,7 @@ testWindow::testWindow(QWidget *)
     fileMenu = new QMenu;
     menuBar->addAction("&File");
     QAction *action = fileMenu->addAction("&Exit");
-    action->setShortcut(Qt::ALT + Qt::Key_Q);
+    action->setShortcut(Qt::ALT | Qt::Key_Q);
 
     connect(action, SIGNAL(triggered()), qApp, SLOT(quit()));
 
